==> apache-cassandra-sidecar-0.1.0-src.tar.gz: apache-cassandra-sidecar-0.1.0-src/server/src/test/java/org/apache/cassandra/sidecar/acl/authentication/AuthenticationHandlerFactoryRegistryTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.cassandra.sidecar.acl.authentication;

import org.junit.jupiter.api.Test;

import org.apache.cassandra.sidecar.acl.IdentityToRoleCache;

import static org.assertj.core.api.Assertions.assertThat;
import static org.assertj.core.api.AssertionsForClassTypes.assertThatThrownBy;
import static org.mockito.Mockito.mock;

/**
 * Test for {@link org.apache.cassandra.sidecar.acl.authentication.AuthenticationHandlerFactoryRegistry}
 */
class AuthenticationHandlerFactoryRegistryTest
{
    @Test
    void testRegisteringNullFactory()
    {
        AuthenticationHandlerFactoryRegistry registry = new AuthenticationHandlerFactoryRegistry();
        assertThatThrownBy(() -> registry.register(null)).isInstanceOf(NullPointerException.class);
    }

    @Test
    void testRetrievingFactory()
    {
        AuthenticationHandlerFactoryRegistry registry = new AuthenticationHandlerFactoryRegistry();
        IdentityToRoleCache identityToRoleCache = mock(IdentityToRoleCache.class);
        MutualTlsAuthenticationHandlerFactory mutualTlsAuthenticationHandlerFactory = new MutualTlsAuthenticationHandlerFactory(identityToRoleCache);
        registry.register(mutualTlsAuthenticationHandlerFactory);
        assertThat(registry.getFactory(MutualTlsAuthenticationHandlerFactory.class.getName())).isNotNull();
    }
}

==> apache-cassandra-sidecar-0.2.0-src.tar.gz: apache-cassandra-sidecar-0.2.0-src/server/src/test/java/org/apache/cassandra/sidecar/acl/authentication/AuthenticationHandlerFactoryRegistryTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.cassandra.sidecar.acl.authentication;

import org.junit.jupiter.api.Test;

import org.apache.cassandra.sidecar.acl.AdminIdentityResolver;
import org.apache.cassandra.sidecar.acl.IdentityToRoleCache;

import static org.assertj.core.api.Assertions.assertThat;
import static org.assertj.core.api.AssertionsForClassTypes.assertThatThrownBy;
import static org.mockito.Mockito.mock;

/**
 * Test for {@link org.apache.cassandra.sidecar.acl.authentication.AuthenticationHandlerFactoryRegistry}
 */
class AuthenticationHandlerFactoryRegistryTest
{
    @Test
    void testRegisteringNullFactory()
    {
        AuthenticationHandlerFactoryRegistry registry = new AuthenticationHandlerFactoryRegistry();
        assertThatThrownBy(() -> registry.register(null)).isInstanceOf(NullPointerException.class);
    }

    @Test
    void testRetrievingFactory()
    {
        AuthenticationHandlerFactoryRegistry registry = new AuthenticationHandlerFactoryRegistry();
        IdentityToRoleCache identityToRoleCache = mock(IdentityToRoleCache.class);
        AdminIdentityResolver mockAdminIdentityResolver = mock(AdminIdentityResolver.class);
        MutualTlsAuthenticationHandlerFactory mutualTlsAuthenticationHandlerFactory = new MutualTlsAuthenticationHandlerFactory(identityToRoleCache,
                                                                                                                                mockAdminIdentityResolver);
        registry.register(mutualTlsAuthenticationHandlerFactory);
        assertThat(registry.getFactory(MutualTlsAuthenticationHandlerFactory.class.getName())).isNotNull();
    }
}
